package com.android.sync;

import android.app.Service;
import android.content.Intent;
import android.os.Handler;
import android.os.IBinder;
import android.os.SystemProperties;
import android.util.Log;

import java.io.IOException;

public class SyncService extends Service {

    private Handler handler = new Handler();
    private Runnable syncRunnable = new Runnable() {
        @Override
        public void run() {
            // 执行同步操作
            performSync();

            // 获取系统属性中的同步间隔，默认为 10000 毫秒（10秒）
            int syncInterval = Integer.parseInt(SystemProperties.get("sync.interval", "10000"));
            handler.postDelayed(this, syncInterval);
        }
    };

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        handler.post(syncRunnable);
        return START_STICKY;
    }

    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    @Override
    public void onDestroy() {
        handler.removeCallbacks(syncRunnable);
        super.onDestroy();
    }

    private void performSync() {
            // 启动一个新的线程来执行 sync 操作
        new Thread(() -> {
        try {
            // 执行 sync 命令，将内存中的数据写入磁盘
            Runtime.getRuntime().exec("sync");
            Log.d("SyncService", "Sync operation performed.");
        } catch (IOException e) {
            e.printStackTrace();
        }
        }).start(); 
    }
}
